==> jmb.tools-0.4.6.tar.gz: jmb.tools-0.4.6/jmb/tools/main.py <==
"""
Qui si va per cominciare
la bella nuda al bagno
la forza muscolare
si vede l'uomo ragno!
"""
import os

import click

from jmb import tools
from jmb.tools import configure_logging
from conf import read, configure
from . import test, kick, port, register, conf  #, config, go, sync

config_filename = read.get_config_filename()

@click.group()
@click.option('-f', '--conf-file', help="The configuration file", type=click.Path(),
              default=config_filename)
@click.option('-v', '--verbose', count=True, help="Be verbose, reasonably")
@click.option('-l', '--level', default='INFO',
              help="the debugging level for the logger (default: info)")
@click.option('-c', '--console', is_flag=True, default=False, help="Logger should also go to console")
@click.option('-n', '--dry-run', is_flag=True, help="Don't run really")
@click.option('--nginx-conf', '-N', help="nginx enabled base (def: {})".format(tools.NGINX_ENABLED_DIR),
              default=tools.NGINX_ENABLED_DIR)
@click.option('--letsencrypt-conf', '-l', default=tools.LETSENCRYPT_CONF_DIR,
              help="nginx enabled base (def: {})".format(tools.LETSENCRYPT_CONF_DIR),
              )
@click.version_option()
@click.pass_context
def cli(ctx, conf_file, verbose, dry_run, level, console, nginx_conf, letsencrypt_conf):

    ctx.obj = read.read_config_file(conf_file)
    ctx.obj.filename = conf_file
    ctx.verbose = verbose
    ctx.dry_run = dry_run
    ctx.help_option_names = ['-h', '--help', '--ajiuto']
    configure_logging('jmb', level=level, console=console)
    tools.NGINX_ENABLED_DIR = nginx_conf
    tools.LETSENCRYPT_CONF_DIR = letsencrypt_conf

#CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
cli.add_command(test.test)
cli.add_command(kick.kick)
cli.add_command(port.port)
cli.add_command(register.register)
cli.add_command(conf.conf)

if __name__ == '__main__':
    cli(obj={})

==> jmb.tools-0.6.1.tar.gz: jmb.tools-0.6.1/jmb/tools/main.py <==
"""
Qui si va per cominciare
la bella nuda al bagno
la forza muscolare
si vede l'uomo ragno!
"""
import os

import click

from jmb import tools
from jmb.tools import configure_logging
from conf import read, configure
from . import test, kick, port, register, conf  #, config, go, sync

config_filename = read.get_config_filename()

@click.group()
@click.option('-f', '--conf-file', help="The configuration file", type=click.Path(),
              default=config_filename)
@click.option('-v', '--verbose', count=True, help="Be verbose, reasonably")
@click.option('-l', '--level', default='INFO',
              help="the debugging level for the logger (default: info)")
@click.option('-c', '--console', is_flag=True, default=False, help="Logger should also go to console")
@click.option('-n', '--dry-run', is_flag=True, help="Don't run really")
@click.option('--nginx-conf', '-N', help="nginx enabled base (def: {})".format(tools.NGINX_ENABLED_DIR),
              default=tools.NGINX_ENABLED_DIR)
@click.option('-L', '--letsencrypt-conf', default=tools.LETSENCRYPT_CONF_DIR,
              help="nginx enabled base (def: {})".format(tools.LETSENCRYPT_CONF_DIR),
              )
@click.version_option()
@click.pass_context
def cli(ctx, conf_file, verbose, dry_run, level, console, nginx_conf, letsencrypt_conf):

    ctx.obj = read.read_config_file(conf_file)
    ctx.obj.filename = conf_file
    ctx.verbose = verbose
    ctx.dry_run = dry_run
    ctx.help_option_names = ['-h', '--help', '--ajiuto']
    configure_logging('jmb', level=level, console=console)
    tools.NGINX_ENABLED_DIR = nginx_conf
    tools.LETSENCRYPT_CONF_DIR = letsencrypt_conf

#CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
cli.add_command(test.test)
cli.add_command(kick.kick)
cli.add_command(port.port)
cli.add_command(register.register)
cli.add_command(conf.conf)

if __name__ == '__main__':
    cli(obj={})
